package project

import (
	"fmt"
	"os"
	"os/exec"

	"github.com/spf13/cobra"
	"github.com/spf13/viper"

	"gitea.libretechconsulting.com/rmcguire/git-project-manager/cmd/util"
)

var projectRunCmd = &cobra.Command{
	Use:     "run",
	Short:   "Run the project (e.g. go run .)",
	Aliases: []string{"exec", "r"},
	Long:    util.ProjRunCmdLong,
	Run:     projectRunCmdRun,
}

func projectRunCmdRun(cmd *cobra.Command, args []string) {
	remotes := viper.GetStringSlice(util.FlagRemote)
	fzfOpts := &util.FzfProjectOpts{
		Ctx:     cmd.Context(),
		Search:  utils.SearchStringFromArgs(args),
		Remotes: remotes,
	}
	project := utils.FzfCwdOrSearchProjectAliases(fzfOpts)
	if project == nil {
		utils.Logger().Fatal("No project selected, nothing to open")
	}

	lang := project.GetLanguage()

	if lang == nil {
		utils.Logger().Fatal("Git remote isn't sure what language this project is... can't run.")
	}

	utils.Logger().Debug(fmt.Sprintf("Project is written in %s, %.2f%% coverage", lang.Name, lang.Percentage))

	switch lang.Name {
	case "Go":
		cmdArgs := []string{"run", "."}                             // Run from cwd
		cmdArgs = append(cmdArgs, args[1:]...)                      // Support flags from shell command
		cmd := exec.CommandContext(cmd.Context(), "go", cmdArgs...) // Honor parent context
		cmd.Env = os.Environ()
		cmd.Stdout = os.Stdout
		cmd.Stderr = os.Stderr
		cmd.Run()
	}
}

func init() {
	ProjectCmd.AddCommand(projectRunCmd)
}
